@@ -3,7 +3,7 @@ use crate::{LogLevel, Status};
 use anyhow::{anyhow, Context, Result};
 use chrono::{DateTime, Utc};
 use colored::*;
-use log::{debug, error, info, trace, warn, Log};
+use log::{debug, error, info, trace, warn};
 use serde::{Deserialize, Serialize};
 use std::fmt::{Debug, Display, Formatter};
 use std::path::{Path, PathBuf};
