@@ -1,5 +1,7 @@
 mod status;
 pub use crate::status::Status;
+mod log_level;
+pub use crate::log_level::LogLevel;
 mod command;
 pub use crate::command::Command;
 mod storage;
